@@ -220,9 +220,6 @@ RFX_CONTEXT* rfx_context_new(BOOL encoder)
 
 	priv->log = WLog_Get("com.freerdp.codec.rfx");
 	WLog_OpenAppender(priv->log);
-#ifdef WITH_DEBUG_RFX
-	WLog_SetLogLevel(priv->log, WLOG_DEBUG);
-#endif
 	priv->TilePool = ObjectPool_New(TRUE);
 
 	if (!priv->TilePool)
@@ -388,6 +385,11 @@ static RFX_TILE* rfx_message_get_tile(RFX_MESSAGE* message, UINT32 index)
 	return message->tiles[index];
 }
 
+static const RFX_RECT* rfx_message_get_rect_const(const RFX_MESSAGE* message, UINT32 index)
+{
+	return &message->rects[index];
+}
+
 static RFX_RECT* rfx_message_get_rect(RFX_MESSAGE* message, UINT32 index)
 {
 	return &message->rects[index];
@@ -640,7 +642,7 @@ static BOOL rfx_process_message_frame_end(RFX_CONTEXT* context, RFX_MESSAGE* mes
 static BOOL rfx_process_message_region(RFX_CONTEXT* context, RFX_MESSAGE* message, wStream* s,
                                        UINT16* pExpectedBlockType)
 {
-	int i;
+	UINT16 i;
 	UINT16 regionType;
 	UINT16 numTileSets;
 	RFX_RECT* tmpRects;
@@ -1069,7 +1071,10 @@ BOOL rfx_process_message(RFX_CONTEXT* context, const BYTE* data, UINT32 length,
 			UINT8 channelId;
 
 			if (Stream_GetRemainingLength(s) < 2)
+			{
+				WLog_ERR(TAG, "extraBlockLen too small(%" PRIuz ")", Stream_GetRemainingLength(s));
 				return FALSE;
+			}
 
 			extraBlockLen = 2;
 			Stream_Read_UINT8(s, codecId);   /* codecId (1 byte) must be set to 0x01 */
@@ -1210,6 +1215,9 @@ BOOL rfx_process_message(RFX_CONTEXT* context, const BYTE* data, UINT32 length,
 				                        NULL, FREERDP_FLIP_NONE))
 				{
 					region16_uninit(&updateRegion);
+					WLog_ERR(TAG,
+					         "nbUpdateRectx[% " PRIu32 " (%" PRIu32 ")] freerdp_image_copy failed",
+					         j, nbUpdateRects);
 					return FALSE;
 				}
 
@@ -1224,6 +1232,7 @@ BOOL rfx_process_message(RFX_CONTEXT* context, const BYTE* data, UINT32 length,
 		return TRUE;
 	}
 
+	WLog_ERR(TAG, "%s failed", __FUNCTION__);
 	return FALSE;
 }
 
@@ -1431,8 +1440,8 @@ static BOOL setupWorkers(RFX_CONTEXT* context, int nbTiles)
 	return TRUE;
 }
 
-RFX_MESSAGE* rfx_encode_message(RFX_CONTEXT* context, const RFX_RECT* rects, int numRects,
-                                BYTE* data, int w, int h, int s)
+RFX_MESSAGE* rfx_encode_message(RFX_CONTEXT* context, const RFX_RECT* rects, size_t numRects,
+                                const BYTE* data, UINT32 w, UINT32 h, size_t s)
 {
 	const UINT32 width = (UINT32)w;
 	const UINT32 height = (UINT32)h;
@@ -1570,7 +1579,8 @@ RFX_MESSAGE* rfx_encode_message(RFX_CONTEXT* context, const RFX_RECT* rects, int
 					tile->allocated = FALSE;
 				}
 
-				tile->data = &data[(ay * scanline) + (ax * bytesPerPixel)];
+				/* Cast away const */
+				tile->data = (BYTE*)&data[(ay * scanline) + (ax * bytesPerPixel)];
 				tile->quantIdxY = context->quantIdxY;
 				tile->quantIdxCb = context->quantIdxCb;
 				tile->quantIdxCr = context->quantIdxCr;
@@ -1666,10 +1676,10 @@ skip_encoding_loop:
 	return NULL;
 }
 
-static RFX_MESSAGE* rfx_split_message(RFX_CONTEXT* context, RFX_MESSAGE* message, int* numMessages,
-                                      int maxDataSize)
+static RFX_MESSAGE* rfx_split_message(RFX_CONTEXT* context, RFX_MESSAGE* message,
+                                      size_t* numMessages, size_t maxDataSize)
 {
-	int i, j;
+	size_t i, j;
 	UINT32 tileDataSize;
 	RFX_MESSAGE* messages;
 	maxDataSize -= 1024; /* reserve enough space for headers */
@@ -1719,9 +1729,9 @@ free_messages:
 	return NULL;
 }
 
-RFX_MESSAGE* rfx_encode_messages(RFX_CONTEXT* context, const RFX_RECT* rects, int numRects,
-                                 BYTE* data, int width, int height, int scanline, int* numMessages,
-                                 int maxDataSize)
+RFX_MESSAGE* rfx_encode_messages_ex(RFX_CONTEXT* context, const RFX_RECT* rects, size_t numRects,
+                                    const BYTE* data, UINT32 width, UINT32 height, UINT32 scanline,
+                                    size_t* numMessages, size_t maxDataSize)
 {
 	RFX_MESSAGE* message;
 	RFX_MESSAGE* messageList;
@@ -1740,7 +1750,7 @@ RFX_MESSAGE* rfx_encode_messages(RFX_CONTEXT* context, const RFX_RECT* rects, in
 	return messageList;
 }
 
-static BOOL rfx_write_message_tileset(RFX_CONTEXT* context, wStream* s, RFX_MESSAGE* message)
+static BOOL rfx_write_message_tileset(RFX_CONTEXT* context, wStream* s, const RFX_MESSAGE* message)
 {
 	int i;
 	RFX_TILE* tile;
@@ -1787,7 +1797,8 @@ static BOOL rfx_write_message_tileset(RFX_CONTEXT* context, wStream* s, RFX_MESS
 	return TRUE;
 }
 
-static BOOL rfx_write_message_frame_begin(RFX_CONTEXT* context, wStream* s, RFX_MESSAGE* message)
+static BOOL rfx_write_message_frame_begin(RFX_CONTEXT* context, wStream* s,
+                                          const RFX_MESSAGE* message)
 {
 	if (!Stream_EnsureRemainingCapacity(s, 14))
 		return FALSE;
@@ -1801,7 +1812,7 @@ static BOOL rfx_write_message_frame_begin(RFX_CONTEXT* context, wStream* s, RFX_
 	return TRUE;
 }
 
-static BOOL rfx_write_message_region(RFX_CONTEXT* context, wStream* s, RFX_MESSAGE* message)
+static BOOL rfx_write_message_region(RFX_CONTEXT* context, wStream* s, const RFX_MESSAGE* message)
 {
 	int i;
 	UINT32 blockLen;
@@ -1819,7 +1830,7 @@ static BOOL rfx_write_message_region(RFX_CONTEXT* context, wStream* s, RFX_MESSA
 
 	for (i = 0; i < message->numRects; i++)
 	{
-		const RFX_RECT* rect = rfx_message_get_rect(message, i);
+		const RFX_RECT* rect = rfx_message_get_rect_const(message, i);
 		/* Clipping rectangles are relative to destLeft, destTop */
 		Stream_Write_UINT16(s, rect->x);      /* x (2 bytes) */
 		Stream_Write_UINT16(s, rect->y);      /* y (2 bytes) */
@@ -1832,7 +1843,8 @@ static BOOL rfx_write_message_region(RFX_CONTEXT* context, wStream* s, RFX_MESSA
 	return TRUE;
 }
 
-static BOOL rfx_write_message_frame_end(RFX_CONTEXT* context, wStream* s, RFX_MESSAGE* message)
+static BOOL rfx_write_message_frame_end(RFX_CONTEXT* context, wStream* s,
+                                        const RFX_MESSAGE* message)
 {
 	if (!Stream_EnsureRemainingCapacity(s, 8))
 		return FALSE;
@@ -1844,7 +1856,7 @@ static BOOL rfx_write_message_frame_end(RFX_CONTEXT* context, wStream* s, RFX_ME
 	return TRUE;
 }
 
-BOOL rfx_write_message(RFX_CONTEXT* context, wStream* s, RFX_MESSAGE* message)
+BOOL rfx_write_message(RFX_CONTEXT* context, wStream* s, const RFX_MESSAGE* message)
 {
 	if (context->state == RFX_STATE_SEND_HEADERS)
 	{
@@ -1865,8 +1877,8 @@ BOOL rfx_write_message(RFX_CONTEXT* context, wStream* s, RFX_MESSAGE* message)
 	return TRUE;
 }
 
-BOOL rfx_compose_message(RFX_CONTEXT* context, wStream* s, const RFX_RECT* rects, int numRects,
-                         BYTE* data, int width, int height, int scanline)
+BOOL rfx_compose_message(RFX_CONTEXT* context, wStream* s, const RFX_RECT* rects, size_t numRects,
+                         const BYTE* data, UINT32 width, UINT32 height, UINT32 scanline)
 {
 	RFX_MESSAGE* message;
 	BOOL ret = TRUE;
@@ -1879,3 +1891,15 @@ BOOL rfx_compose_message(RFX_CONTEXT* context, wStream* s, const RFX_RECT* rects
 	rfx_message_free(context, message);
 	return ret;
 }
+
+RFX_MESSAGE* rfx_encode_messages(RFX_CONTEXT* context, const RFX_RECT* rects, int numRects,
+                                 const BYTE* data, int width, int height, int scanline,
+                                 int* numMessages, int maxDataSize)
+{
+	size_t tmp;
+	RFX_MESSAGE* msg = rfx_encode_messages_ex(context, rects, numRects, data, width, height,
+	                                          scanline, &tmp, maxDataSize);
+	if (numMessages)
+		*numMessages = tmp;
+	return msg;
+}
