@@ -21,8 +21,10 @@
 #include "config.h"
 #endif
 
+#include <openssl/objects.h>
+
 #include <winpr/crt.h>
-#include <winpr/crypto.h>
+#include <winpr/assert.h>
 
 #include <freerdp/log.h>
 #include <freerdp/crypto/crypto.h>
@@ -725,11 +727,13 @@ char* crypto_cert_get_upn(X509* x509)
 	return result;
 }
 
+#if !defined(DEFINE_NO_DEPRECATED)
 /* Deprecated name.*/
 void crypto_cert_subject_alt_name_free(int count, int* lengths, char** alt_names)
 {
 	crypto_cert_dns_names_free(count, lengths, alt_names);
 }
+#endif
 
 void crypto_cert_dns_names_free(int count, int* lengths, char** dns_names)
 {
@@ -751,11 +755,13 @@ void crypto_cert_dns_names_free(int count, int* lengths, char** dns_names)
 	}
 }
 
+#if !defined(DEFINE_NO_DEPRECATED)
 /* Deprecated name.*/
 char** crypto_cert_subject_alt_name(X509* xcert, int* count, int** lengths)
 {
 	return crypto_cert_get_dns_names(xcert, count, lengths);
 }
+#endif
 
 char** crypto_cert_get_dns_names(X509* x509, int* count, int** lengths)
 {
@@ -842,9 +848,7 @@ BOOL x509_verify_certificate(CryptoCert cert, const char* certificate_store_path
 	                    NULL);
 #endif
 
-	lookup = X509_STORE_add_lookup(cert_ctx, X509_LOOKUP_file());
-
-	if (lookup == NULL)
+	if (X509_STORE_set_default_paths(cert_ctx) != 1)
 		goto end;
 
 	lookup = X509_STORE_add_lookup(cert_ctx, X509_LOOKUP_hash_dir());
@@ -941,3 +945,53 @@ out_free_issuer:
 	free(issuer);
 	free(subject);
 }
+
+WINPR_MD_TYPE crypto_cert_get_signature_alg(X509* xcert)
+{
+	WINPR_ASSERT(xcert);
+
+	const int nid = X509_get_signature_nid(xcert);
+
+	int hash_nid = 0;
+	if (OBJ_find_sigid_algs(nid, &hash_nid, NULL) != 1)
+		return WINPR_MD_NONE;
+
+	switch (hash_nid)
+	{
+		case NID_md2:
+			return WINPR_MD_MD2;
+		case NID_md4:
+			return WINPR_MD_MD4;
+		case NID_md5:
+			return WINPR_MD_MD5;
+		case NID_sha1:
+			return WINPR_MD_SHA1;
+		case NID_sha224:
+			return WINPR_MD_SHA224;
+		case NID_sha256:
+			return WINPR_MD_SHA256;
+		case NID_sha384:
+			return WINPR_MD_SHA384;
+		case NID_sha512:
+			return WINPR_MD_SHA512;
+		case NID_ripemd160:
+			return WINPR_MD_RIPEMD160;
+#if (OPENSSL_VERSION_NUMBER >= 0x1010101fL) || defined(LIBRESSL_VERSION_NUMBER)
+		case NID_sha3_224:
+			return WINPR_MD_SHA3_224;
+		case NID_sha3_256:
+			return WINPR_MD_SHA3_256;
+		case NID_sha3_384:
+			return WINPR_MD_SHA3_384;
+		case NID_sha3_512:
+			return WINPR_MD_SHA3_512;
+#endif
+		case NID_shake128:
+			return WINPR_MD_SHAKE128;
+		case NID_shake256:
+			return WINPR_MD_SHAKE256;
+		case NID_undef:
+		default:
+			return WINPR_MD_NONE;
+	}
+}
